Main Contributors
=================

Main contributors to code and ideas in alphabetical order:
----------------------------------------------------------

* Mike Gevaert @ BBP
* Lida Kanari @ BBP
* Juan Palacios @ BBP
* Eleftherios Zisis @ BBP

Maintainer / release manager
----------------------------

* [Benoit Coste @ BBP](https://github.com/wizmer)
* [Michael Gevaert @ BBP](https://github.com/mgeplf)

